# general info
NAME="systemd"
DESC="System and service manager"
VERSION="256"

# required files
FILES=("https://github.com/systemd/systemd/archive/v${VERSION}/systemd-${VERSION}.tar.gz")
HASHES=("4825b82700e1acf02ba81885652406e75d0c674c129a1a7e488e5b5200a17998")

# install and build depends
DEPENDS=(
  "acl" "bash" "dbus"
  "kbd" "kmod" "libcap"
  "libelf" "libgcrypt" "libidn2"
  "openssl" "libxcrypt" "libseccomp"
  "xz" "util-linux" "pcre2"
  "linux-pam"
)
BUILD=("shadow" "curl" "pypi-jinja2" "libxslt")

PACKAGE(){
  tar xf "${NAME}-${VERSION}.tar.gz"
  cd "${NAME}-${VERSION}"

  sed -i -e 's/GROUP="render"/GROUP="video"/' \
       -e 's/GROUP="sgx", //' rules.d/50-udev-default.rules.in

  mkdir -p build
  cd       build

  meson setup                                      \
      --prefix=/usr                                \
      --buildtype=release                          \
      -Ddefault-dnssec=no                          \
      -Dfirstboot=false                            \
      -Dinstall-tests=false                        \
      -Dldconfig=false                             \
      -Dsysusers=false                             \
      -Drpmmacrosdir=no                            \
      -Dhomed=disabled                             \
      -Duserdb=false                               \
      -Dman=enabled                                \
      -Dmode=release                               \
      -Dpamconfdir=no                              \
      -Ddev-kvm-mode=0660                          \
      -Dnobody-group=nogroup                       \
      -Dsysupdate=disabled                         \
      -Dukify=disabled                             \
      -Dsbat-distro='matter'                       \
      -Dsbat-distro-summary='MatterLinux'          \
      -Ddns-servers="94.140.14.14#94.140.15.15"    \
      -Ddocdir="/usr/share/doc/systemd-${VERSION}" \
      ..

  ninja

  install -dm755 "${ROOTDIR}/usr/share/man"
  install -dm755 "${ROOTDIR}/etc"

  DESTDIR="${ROOTDIR}" ninja install

  cd ../.. && rm -r "${NAME}-${VERSION}"
}

INSTALL(){
  useradd systemd-timesync
  useradd systemd-resolve
  useradd systemd-network
  systemd-machine-id-setup
  exit 0
}
